# Provenance for CELINE Core Ontology Documentation (https://w3id.org/celine/v0.3)

- https://w3id.org/celine/v0.3 is a revision of the previous version https://w3id.org/celine/v0.2
- The ontology documentation was the result of using the Widoco tool (which itself uses LODE for generating the crossreference section).
- The documentation was generated at 2026-03-23

back to documentation. TTL format